@@ -11,7 +11,7 @@ has 'header' => (
         sub { { id => '\x{04}1.4', x0 => 0, y0 => 0, x1 => 0, y1 => 0 } }
 );
 
-sub extensions { return 'idf' };
+sub extensions { return 'idf' }
 
 no Moose;
 
