@@ -25,7 +25,7 @@ method.
 
 =cut
 
-sub read { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub read {    ## no critic (Subroutines::ProhibitBuiltinHomonyms)
     my ( $self, $image, $fh, $options ) = @_;
     $options ||= {};
     $fh = _get_fh( $fh );
@@ -47,7 +47,8 @@ sub _get_fh {
     my $fh = $file;
     if ( !ref $fh ) {
         undef $fh;
-        open $fh, '<', $file or croak "Unable to open '$file': $!"; ## no critic (InputOutput::RequireBriefOpen)
+        open $fh, '<', $file    ## no critic (InputOutput::RequireBriefOpen)
+            or croak "Unable to open '$file': $!";
     }
 
     binmode( $fh );
